@@ -622,8 +622,8 @@ class wsgiresponse(object):
 
 
 def wsgiapplication(app_maker):
-    '''For compatibility with old CGI scripts. A plain hgweb() or hgwebdir()
-    can and should now be used as a WSGI application.'''
+    """For compatibility with old CGI scripts. A plain hgweb() or hgwebdir()
+    can and should now be used as a WSGI application."""
     application = app_maker()
 
     def run_wsgi(env, respond):
